@@ -1,6 +1,6 @@
 package Archive::Tar::Builder;
 
-# Copyright (c) 2014, cPanel, Inc.
+# Copyright (c) 2012, cPanel, Inc.
 # All rights reserved.
 # http://cpanel.net/
 #
@@ -10,22 +10,20 @@ package Archive::Tar::Builder;
 use strict;
 use warnings;
 
+use Exporter ();
 use XSLoader ();
 
 use Archive::Tar::Builder::UserCache ();
 
-our $VERSION = '1.10_0001';
+BEGIN {
+    use vars qw(@ISA $VERSION);
+
+    our @ISA     = qw(Exporter);
+    our $VERSION = '1.1';
+}
 
 XSLoader::load( 'Archive::Tar::Builder', $VERSION );
 
-sub archive {
-    my ( $self, @members ) = @_;
-
-    die('No paths to archive specified') unless @members;
-
-    return $self->archive_as( map { $_ => $_ } @members );
-}
-
 __END__
 
 =head1 NAME
@@ -70,11 +68,6 @@ cause Archive::Tar::Builder to die() at the end of the stream.
 
 When set, symlinks encountered while archiving are followed.
 
-=item C<gnu_extensions>
-
-When set, support for arbitrarily long pathnames is enabled using the GNU
-LongLink format.
-
 =back
 
 =back
@@ -184,23 +177,9 @@ C<ignore_errors> is not enabled.  Finally, reset any other error data present.
 
 =back
 
-=head1 AUTHOR
-
-Written by Xan Tronix <xan@cpan.org>
-
-=head1 CONTRIBUTORS
-
-=over
-
-=item Rikus Goodell <rikus.goodell@cpanel.net>
-
-=item Brian Carlson <brian.carlson@cpanel.net>
-
-=back
-
 =head1 COPYRIGHT
 
-Copyright (c) 2014, cPanel, Inc.
+Copyright (c) 2012, cPanel, Inc.
 All rights reserved.
 http://cpanel.net/
 
